@@ -13,6 +13,7 @@ AJAX_HEADERS = {
     "User-Agent": "Mozilla/5.0"
 }
 CHINFO_URL = "http://www.filmon.com/ajax/getChannelInfo"
+VODINFO_URL = "http://www.filmon.com/vod/info/{0}"
 QUALITY_WEIGHTS = {
     "high": 720,
     "low": 480
@@ -23,7 +24,7 @@ SWF_URL = "http://www.filmon.com/tv/modules/FilmOnTV/files/flashapp/filmon/Filmo
 class Filmon(Plugin):
     @classmethod
     def can_handle_url(cls, url):
-        return re.match("^http(s)?://(\w+\.)?filmon.com/tv/.+", url)
+        return re.match("^http(s)?://(\w+\.)?filmon.com/(tv|vod).+", url)
 
     @classmethod
     def stream_weight(cls, key):
@@ -33,6 +34,18 @@ class Filmon(Plugin):
 
         return Plugin.stream_weight(key)
 
+    def _get_rtmp_app(self, rtmp):
+        parsed = urlparse(rtmp)
+        if not parsed.scheme.startswith("rtmp"):
+            return
+
+        if parsed.query:
+            app = "{0}?{1}".format(parsed.path[1:], parsed.query)
+        else:
+            app = parsed.path[1:]
+
+        return app
+
     def _get_streams(self):
         if not RTMPStream.is_usable(self.session):
             raise PluginError("rtmpdump is not usable and required by Filmon plugin")
@@ -41,6 +54,10 @@ class Filmon(Plugin):
         self.rsession = requests.session()
         res = urlget(self.url, session=self.rsession)
 
+        match = re.search("movie_id=(\d+)", res.text)
+        if match:
+            return self._get_vod_stream(match.group(1))
+
         match = re.search("/channels/(\d+)/extra_big_logo.png", res.text)
         if not match:
             return
@@ -72,15 +89,10 @@ class Filmon(Plugin):
         if not (rtmp and playpath):
             raise NoStreamsError(self.url)
 
-        parsed = urlparse(rtmp)
-        if not parsed.scheme.startswith("rtmp"):
+        app = self._get_rtmp_app(rtmp)
+        if not app:
             raise NoStreamsError(self.url)
 
-        if parsed.query:
-            app = "{0}?{1}".format(parsed.path[1:], parsed.query)
-        else:
-            app = parsed.path[1:]
-
         return RTMPStream(self.session, {
             "rtmp": rtmp,
             "pageUrl": self.url,
@@ -90,4 +102,40 @@ class Filmon(Plugin):
             "live": True
         })
 
+    def _get_vod_stream(self, movie_id):
+        res = urlopen(VODINFO_URL.format(movie_id), headers=AJAX_HEADERS,
+                      session=self.rsession)
+        json = res_json(res)
+        json = json and json.get("data")
+        json = json and json.get("streams")
+
+        if not json:
+            raise NoStreamsError(self.url)
+
+        streams = {}
+        for quality in ("low", "high"):
+            stream = json.get(quality)
+            if not stream:
+                continue
+
+            rtmp = stream.get("url")
+            app = self._get_rtmp_app(rtmp)
+            if not app:
+                continue
+
+            playpath = stream.get("name")
+            if ".mp4" in playpath:
+                playpath = "mp4:" + playpath
+
+            streams[quality] = RTMPStream(self.session, {
+                "rtmp": rtmp,
+                "pageUrl": self.url,
+                "swfUrl": SWF_URL,
+                "playpath": playpath,
+                "app": app,
+            })
+
+        return streams
+
+
 __plugin__ = Filmon
